#!/bin/sh
# *******************************************************************************
#  Materiale su licenza - Proprietà di IBM
#  (c) Copyright IBM Corporation 2006, 2012. Tutti i diritti riservati.
#
#  Nota relativa a limitazioni dei diritti per gli utenti del Governo degli Stati Uniti:
#  L'uso, la duplicazione o la divulgazione sono limitati dal GSA ADP Schedule
#  Contract con IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Definire le variabili d'ambiente corrispondenti ai
# # parametri di script ccm_upgrade.sh e ai relativi valori predefiniti
# #
# #===========================================================
# #
# # Questo file viene letto all'inizio dell'esecuzione dello script
# # ccm_upgrade.sh. Esso imposta una variabile di ambiente
# # per parametro valido con valore predefinito.
# #                                                           #
# # Gli utenti possono modificare il valore predefinito per   #
# # avviare lo script ccm_upgrade.sh con i propri valori     #
# # senza dover immettere il parametro e il corrispondente    #
# # valore manualmente sulla riga comandi.
# #
# # AVVERTENZA:
# # Non tutte le variabili devono essere impostate in base
# # all'applicazione correntemente aggiornata.  Leggere attentamente ogni commento
# # prima di modificare il valore.
# #
# #############################################################

# Parametro: -oldApplicationHome
# Uso: -oldApplicationHome <percorso dir>
# Descrizione:
# Percorso completo della directory home dell'applicazione nell'installazione old.
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Questo è un parametro obbligatorio
#  - <percorso dir> deve essere una directory esistente che termina con 'server/conf'
#    ad esempio, /Jazz/IBM/RTC_3.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# Parametro: -applicationContextRoot
# Uso: -applicationContextRoot <root>
# Descrizione:
# 	la root di contesto dell'applicazione.
# Valore predefinito:
# 	ccm
# Limitazioni:
#  - <root> deve essere un nome di directory valido (senza barre iniziali)
#
APPLICATION_CONTEXT_ROOT=

# Parametro: -oldApplicationVersion
# Uso: -oldApplicationVersion <versione>
# Descrizione:
#  la versione di CCM che viene aggiornata.  Per impostazione predefinita, questa viene
# determinata eseguendo repotools -version rispetto alla vecchia applicazione.
# Valore predefinito:
# 	<nessuno>
# Limitazioni:
#  - deve essere una stringa di versione completa
#    ad esempio, 3.0.0 o 3.0.1
#
OLD_APPLICATION_VERSION=

# Parametro: -updateTomcatFiles
# Uso: -updateTomcatFiles <yes | no>
# Descrizione:
# Indica se aggiornare i file di configurazione Tomcat.
# Valore predefinito:
# 	yes
# Limitazioni:
#  - Gli unici valori validi sono 'yes' e 'no'
#
UPDATE_TOMCAT_FILES=yes

# Parametro: -oldTomcatHome
# Uso: -oldTomcatHome <percorso dir>
# Descrizione:
# Il percorso completo della directory root Tomcat nell'installazione old.
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Deve essere una directory esistente
#
OLD_TOMCAT_HOME=

# Parametro: -newApplicationHome
# Uso: -newApplicationHome <percorso dir>
# Descrizione:
# Il percorso della directory home dell'applicazione nell'istallazione new.
# Valore predefinito:
# 	conf
# Limitazioni:
#  - Accettato solo per un aggiornamento RTC, QM e RM
#  - Se accettato, questo è un parametro obbligatorio
#  - <percorso dir> deve essere una directory esistente che termina con 'server/conf'
#    ad esempio, /Jazz/IBM/RTC_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Parametro: -newJTSHome
# Uso: -newJTSHome <percorso dir>
# Descrizione:
# 	il percorso della directory di configurazione del server JTS del JTS che sarà utilizzato dalla nuova installazione
# Valore predefinito:
# 	la nuova directory home dell'applicazione
# Limitazioni:
#  - <percorso dir> deve essere una directory esistente che termina per 'server/conf'
#
NEW_JTS_HOME=

# Parametro: -jtsContextRoot
# Uso: -jtsContextRoot <root>
# Descrizione:
# 	la root di contesto del server JTS.
# Valore predefinito:
# 	jts
# Limitazioni:
#  - <root> deve essere una singola directory valida (senza barra iniziale)
#
JTS_CONTEXT_ROOT=jts

# Parametro: -newApplicationTomcatHome
# Uso: -newApplicationTomcatHome <percorso dir>
# Descrizione:
# 	il percorso della directory root Tomcat dell'applicazione nella nuova installazione.
# Valore predefinito:
# 	<nessuno>
#
NEW_TOMCAT_HOME=

# Parametro: -newJTSTomcatHome
# Uso: -newJTSTomcatHome <percorso dir>
# Descrizione:
# 	il percorso della directory root Tomcat JTS nel JTS che sarà utilizzato dalla nuova installazione.
# Valore predefinito:
# 	<nessuno>
#
NEW_JTS_TOMCAT_HOME=

# Parametro: -noPrompt
# Uso: -noPrompt
# Descrizione:
# Non richiede prima di creare o modificare le tabelle
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Gli unici valori validi sono un valore vuoto o 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parametro: -noVerify
# Uso: -noVerify
# Descrizione:
# Non esegue la verifica dei file teamserver.properties.
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Gli unici valori validi sono un valore vuoto o 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parametro: -overwrite
# Uso: -overwrite
# Descrizione:
# Indica se sovrascrivere un file esistente.
# Valore predefinito:
# 	no
# Limitazioni:
#  - Gli unici valori validi sono il valore vuoto o 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parametro: -noStepPrompt
# Uso: -noStepPrompt
# Descrizione:
# Non richiede prima di eseguire un passo.
# Valore predefinito:
# 	false
# Limitazioni:
#  - Gli unici valori validi sono 'true' o 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
